Listener

Struct Listener 

pub struct Listener<T: 'static> { /* private fields */ }
A signal listener that receives ‘events’ from the outside and runs the callback.

This is implemented using effects and normal rw signals. This should be used when it doesn’t make sense to think of it as ‘storing’ a value, like an RwSignal would typically be used for.

Copied/Cloned listeners refer to the same listener.

Implementations

Source

impl<T: Clone + 'static> Listener<T>

pub fn new(cx: Scope, on_val: impl Fn(T) + 'static) -> Listener<T>

pub fn new_empty(cx: Scope) -> Listener<T>

Construct a listener when you can’t yet give it a callback.

Call listen to set a callback.

pub fn scope(&self) -> Scope

pub fn listen(self, on_val: impl Fn(T) + 'static)

Listen for values sent to this listener.

pub fn listen_with(self, cx: Scope, on_val: impl Fn(T) + 'static)

Listen for values sent to this listener.

Allows creating the effect with a custom scope, letting it be disposed of.

pub fn send(&self, v: T)

Send a value to the listener.